@@ -27,13 +27,16 @@
 #include <QGridLayout>
 
 // include files for KDE
-#include <klocale.h>
-#include <kdebug.h>
+#include <KLocalizedString>
+#include "kfourinline_debug.h"
 
 #include "kchatdialog.h"
 
 #define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
 #include <libkdegamesprivate/kgame/kgamechat.h>
+#include <KConfigGroup>
+#include <QDialogButtonBox>
+#include <QVBoxLayout>
 
 // application specific includes
 #include "kwin4player.h"
@@ -42,16 +45,23 @@
 // Constructor for the chat widget. This widget
 // is derived from the libkdegames chat widget
 ChatDlg::ChatDlg(KGame *game,QWidget *parent)
-       : KDialog(parent),mChat(0), mChatDlg(0)
+       : QDialog(parent),mChat(0), mChatDlg(0)
 {
-  setCaption(i18n("Chat Dlg"));
-  setButtons(Ok);
-  setDefaultButton(Ok);
-  showButtonSeparator(true);
+  setWindowTitle(i18n("Chat Dlg"));
+  QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok);
+  QVBoxLayout *mainLayout = new QVBoxLayout;
+  setLayout(mainLayout);
+  QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+  okButton->setDefault(true);
+  okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+  connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
+  connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+  okButton->setDefault(true);
   setModal(false);
   setMinimumSize(QSize(200,200));
   
   QFrame* frame            = new QFrame(this);
+
   QGridLayout* mGridLayout = new QGridLayout(frame);
   QGroupBox* b             = new QGroupBox(i18n("Chat"), frame);
   QVBoxLayout* gboxLay     = new QVBoxLayout(b);
@@ -62,12 +72,12 @@ ChatDlg::ChatDlg(KGame *game,QWidget *parent)
   QPushButton *mButton     = new QPushButton(i18n("Configure..."),frame);
   mGridLayout->addWidget(mButton,1,1);
   
-  setMainWidget(frame);
-  
+  mainLayout->addWidget(frame);
+  mainLayout->addWidget(buttonBox); 
   adjustSize();
   
   mChatDlg                 = new KChatDialog(mChat,frame,true);
-  connect(mButton,SIGNAL(clicked()),mChatDlg,SLOT(show()));
+  connect(mButton, &QPushButton::clicked, mChatDlg, &KChatDialog::show);
 }
 
 // Set the player in who does the chat. This should be the local player.
@@ -75,15 +85,15 @@ void ChatDlg::setPlayer(KWin4Player* p)
 {
   if (!mChat)
   {
-    kError() << "ChatDlg::setPlayer::Chat not defined can't set player";
+    qCCritical(KFOURINLINE_LOG) << "ChatDlg::setPlayer::Chat not defined can't set player";
     return ;
   }
   if (!p)
   {
-    kError() << "ChatDlg::setPlayer::Player not defined can't set player";
+    qCCritical(KFOURINLINE_LOG) << "ChatDlg::setPlayer::Player not defined can't set player";
     return ;
   }
   mChat->setFromPlayer(p);
 }
 
-#include "chatdlg.moc"
+
