@@ -31,17 +31,17 @@
 #include <kstandardgameaction.h>
 #include <kmessagebox.h>
 #include <kfiledialog.h>
-#include <klocale.h>
+#include <KLocalizedString>
 #include <khelpmenu.h>
 #include <kconfig.h>
-#include <kdebug.h>
+#include "kfourinline_debug.h"
 #include <kstandardaction.h>
 #include <kaction.h>
 #include <kstatusbar.h>
 #include <kconfigdialog.h>
 #include <kactioncollection.h>
 #include <kbuttongroup.h>
-#include <kicon.h>
+#include <QIcon>
 #include <kstandarddirs.h>
 #include <kglobal.h>
 #include <kselectaction.h>
@@ -92,7 +92,7 @@ KWin4App::KWin4App(QWidget *parent)
 
   #ifndef NDEBUG
   #ifdef SRC_DIR
-  kDebug() << "Found SRC_DIR =" << SRC_DIR;
+  qCDebug(KFOURINLINE_LOG) << "Found SRC_DIR =" << SRC_DIR;
   KGlobal::dirs()->addResourceDir("kwin4theme",QString(SRC_DIR)+QString("/grafix/"));
   #endif
   #endif
@@ -117,16 +117,16 @@ KWin4App::KWin4App(QWidget *parent)
     if (mThemeDefault.isNull()) mThemeDefault = name;
     if (isDefault) mThemeDefault = name;
     mThemeFiles[name] = file;
-    kDebug() <<  "Found theme("<<i<<"): " <<themeList.at(i) <<" Name(i18n)="<<name<<" File="<<file << " default="<<isDefault;
+    qCDebug(KFOURINLINE_LOG) <<  "Found theme("<<i<<"): " <<themeList.at(i) <<" Name(i18n)="<<name<<" File="<<file << " default="<<isDefault;
   }
   mThemeIndexNo = themeIdxFromName(mThemeDefault);
 
 
   // Setup application
   mDoc = new KWin4Doc(this);
-  kDebug() << "Init doc";
+  qCDebug(KFOURINLINE_LOG) << "Init doc";
   QString aiEngine = mDoc->findProcessName();
-  kDebug() << "Init AI" << aiEngine;
+  qCDebug(KFOURINLINE_LOG) << "Init AI" << aiEngine;
   if (aiEngine.isEmpty())
   {
     KMessageBox::error(this, i18n("Installation error: No AI engine found. Continue without AI."));
@@ -134,7 +134,7 @@ KWin4App::KWin4App(QWidget *parent)
 
  
   // Read properties (before GUI and thememanager but after new document)
-  kDebug() << "read prop";
+  qCDebug(KFOURINLINE_LOG) << "read prop";
   readProperties();
 
 
@@ -144,7 +144,7 @@ KWin4App::KWin4App(QWidget *parent)
 
   // Theme
   QString themeFile = themefileFromIdx(mThemeIndexNo);
-  kDebug() << "Loading theme" << themeFile << " #"<<mThemeIndexNo;
+  qCDebug(KFOURINLINE_LOG) << "Loading theme" << themeFile << " #"<<mThemeIndexNo;
   mTheme  = new ThemeManager(themeFile, this);
   if (mTheme->checkTheme() != 0)
   {
@@ -156,14 +156,13 @@ KWin4App::KWin4App(QWidget *parent)
   // View
   mView   = new KWin4View(UPDATE_TIME, QSize(800,600),mScene,mTheme,this);
   mDoc->setView(mView);
-  connect(mView, SIGNAL(signalQuickStart(COLOUR,KGameIO::IOMode,KGameIO::IOMode,int)), 
-          this, SLOT(quickStart(COLOUR,KGameIO::IOMode,KGameIO::IOMode,int)));
+  connect(mView, &KWin4View::signalQuickStart, this, &KWin4App::quickStart);
 
            
 
 
   // Players (after view)
-  kDebug() << "Init pl";
+  qCDebug(KFOURINLINE_LOG) << "Init pl";
   mDoc->initPlayers();
 
   // Init GUI
@@ -177,7 +176,7 @@ KWin4App::KWin4App(QWidget *parent)
   // Connect signals
   connectDocument();
   // Read global config for document (after initPlayers)
-  mDoc->readConfig(KGlobal::config().data());
+  mDoc->readConfig(KSharedConfig::openConfig().data());
 
   // Check menus
   checkMenus();
@@ -199,13 +198,13 @@ KWin4App::KWin4App(QWidget *parent)
 // Destruct application
 KWin4App::~KWin4App()
 {
-  kDebug() << "~KWin4App()";
+  qCDebug(KFOURINLINE_LOG) << "~KWin4App()";
   delete mDoc;
   delete mView;
   delete mScene;
   delete mTheme;
   delete mMyChatDlg;
-  kDebug() << "~KWin4App()";
+  qCDebug(KFOURINLINE_LOG) << "~KWin4App()";
 }
 
 
@@ -237,7 +236,7 @@ int KWin4App::themeIdxFromName(QString name)
   {
     if (list[i] == name) return i;
   }
-  kError() << "Theme index lookup failed for " << name;
+  qCCritical(KFOURINLINE_LOG) << "Theme index lookup failed for " << name;
   return 0;
 }
 
@@ -329,16 +328,16 @@ void KWin4App::initGUI()
   
   action = actionCollection()->addAction( QLatin1String( "network_conf" ));
   action->setText(i18n("&Network Configuration..."));
-  connect(action, SIGNAL(triggered(bool)), SLOT(configureNetwork()));
+  connect(action, &QAction::triggered, this, &KWin4App::configureNetwork);
 
   action = actionCollection()->addAction( QLatin1String( "network_chat" ));
   action->setText(i18n("Network Chat..."));
-  connect(action, SIGNAL(triggered(bool)), SLOT(configureChat()));
+  connect(action, &QAction::triggered, this, &KWin4App::configureChat);
 
   action = actionCollection()->addAction( QLatin1String( "statistics" ));
-  action->setIcon(KIcon( QLatin1String( "view-statistics" )));
+  action->setIcon(QIcon::fromTheme( QLatin1String( "view-statistics" )));
   action->setText(i18n("&Show Statistics"));
-  connect(action, SIGNAL(triggered(bool)), SLOT(showStatistics()));
+  connect(action, &QAction::triggered, this, &KWin4App::showStatistics);
   action->setToolTip(i18n("Show statistics."));
 
   // Move
@@ -352,10 +351,10 @@ void KWin4App::initGUI()
   themes.sort();
 
   action = actionCollection()->addAction( QLatin1String( "theme" ) , new KSelectAction(i18n("Theme" ), this));
-  action->setIcon(KIcon( QLatin1String( "games-config-theme" )));
+  action->setIcon(QIcon::fromTheme( QLatin1String( "games-config-theme" )));
   ((KSelectAction*)action)->setItems(themes);
-  connect( action, SIGNAL(triggered(int)), SLOT(changeTheme(int)) );
-  kDebug() << "Setting current theme item to" << mThemeIndexNo;
+  connect(action, &QAction::triggered, this, &KWin4App::changeTheme);
+  qCDebug(KFOURINLINE_LOG) << "Setting current theme item to" << mThemeIndexNo;
   ((KSelectAction*)action)->setCurrentItem(mThemeIndexNo);
 
   // Debug
@@ -363,7 +362,7 @@ void KWin4App::initGUI()
   {
     action = actionCollection()->addAction( QLatin1String( "file_debug" ));
     action->setText(i18n("Debug KGame"));
-    connect(action, SIGNAL(triggered(bool)), SLOT(debugKGame()));
+    connect(action, &QAction::triggered, this, &KWin4App::debugKGame);
   }
 }
 
@@ -373,7 +372,7 @@ void KWin4App::changeTheme(int idx)
 {
   mThemeIndexNo = idx;
   QString themeFile = themefileFromIdx(idx);
-  kDebug() << "Select theme" << themeFile;
+  qCDebug(KFOURINLINE_LOG) << "Select theme" << themeFile;
   mTheme->updateTheme(themeFile);
   updateStatusNames();
 }
@@ -382,10 +381,10 @@ void KWin4App::changeTheme(int idx)
 // Create the status bar with the message part, the player part.
 void KWin4App::initStatusBar()
 {
-  statusBar()->insertItem(i18n("Ready"), ID_STATUS_MSG,1);
-  statusBar()->insertPermanentItem(i18n("This leaves space for the mover"),ID_STATUS_MOVER,0);
-  statusBar()->setItemAlignment(ID_STATUS_MOVER, Qt::AlignLeft | Qt::AlignVCenter);
-  statusBar()->setItemAlignment(ID_STATUS_MSG, Qt::AlignLeft | Qt::AlignVCenter);
+  //QT5 statusBar()->insertItem(i18n("Ready"), ID_STATUS_MSG,1);
+  //QT5 statusBar()->insertPermanentItem(i18n("This leaves space for the mover"),ID_STATUS_MOVER,0);
+  //QT5 statusBar()->setItemAlignment(ID_STATUS_MOVER, Qt::AlignLeft | Qt::AlignVCenter);
+  //QT5 statusBar()->setItemAlignment(ID_STATUS_MSG, Qt::AlignLeft | Qt::AlignVCenter);
 
 
   displayStatusbarMover("");
@@ -398,14 +397,10 @@ void KWin4App::initStatusBar()
 void KWin4App::connectDocument()
 {
   // KGame signals
-  connect(mDoc,SIGNAL(signalGameOver(int,KPlayer*,KGame*)),
-         this,SLOT(slotGameOver(int,KPlayer*,KGame*)));
-  connect(mDoc,SIGNAL(signalNextPlayer(int)),
-         this,SLOT(moveDone(int)));
-  connect(mDoc,SIGNAL(signalClientLeftGame(int,int,KGame*)),
-         this,SLOT(networkBroken(int,int,KGame*)));
-  connect(mDoc,SIGNAL(signalGameRun()),
-         this,SLOT(gameRun()));
+  connect(mDoc, &KWin4Doc::signalGameOver, this, &KWin4App::slotGameOver);
+  connect(mDoc, &KWin4Doc::signalNextPlayer, this, &KWin4App::moveDone);
+  connect(mDoc, &KWin4Doc::signalClientLeftGame, this, &KWin4App::networkBroken);
+  connect(mDoc, &KWin4Doc::signalGameRun, this, &KWin4App::gameRun);
 }
 
 
@@ -428,7 +423,7 @@ void KWin4App::changeAction(const char* action, bool enable)
 // Save instance-specific properties. The function is
 void KWin4App::saveProperties(KConfigGroup& grp)
 {
-  kDebug() << "SAVE PROPERTIES for GROUP" << grp.name();
+  qCDebug(KFOURINLINE_LOG) << "SAVE PROPERTIES for GROUP" << grp.name();
 
   // Save current game?
   QString name = QString("current_game")+grp.name();
@@ -436,14 +431,14 @@ void KWin4App::saveProperties(KConfigGroup& grp)
   bool isRunning = (mDoc->gameStatus()==KGame::Run);
   if (isRunning)
   {
-    kDebug() << "Saving" << filename;
+    qCDebug(KFOURINLINE_LOG) << "Saving" << filename;
     mDoc->save(filename);
     grp.writeEntry("CurrentGame", filename);
   }
   else
   {
     QFile file(filename);
-    kDebug() << "Deleting" << file.fileName();
+    qCDebug(KFOURINLINE_LOG) << "Deleting" << file.fileName();
     file.remove();
     grp.deleteEntry("CurrentGame");
   }
@@ -453,16 +448,16 @@ void KWin4App::saveProperties(KConfigGroup& grp)
 // Read instance-specific properties.
 void KWin4App::readProperties(const KConfigGroup& grp)
 {
-  kDebug() << "READ PROPERTIES for GROUP" << grp.name();
+  qCDebug(KFOURINLINE_LOG) << "READ PROPERTIES for GROUP" << grp.name();
 
   QString filename = grp.readEntry("CurrentGame", QString());
-  kDebug() << "Filename is" << filename;
+  qCDebug(KFOURINLINE_LOG) << "Filename is" << filename;
   
   if(!filename.isNull() && QFile::exists(filename))
   {
-    kDebug() << "Loading" << filename;
+    qCDebug(KFOURINLINE_LOG) << "Loading" << filename;
     // TODO: CRASHES mDoc->load(filename);
-    kDebug() << "Loading" << filename << "done";
+    qCDebug(KFOURINLINE_LOG) << "Loading" << filename << "done";
   }
 
 }
@@ -471,7 +466,7 @@ void KWin4App::readProperties(const KConfigGroup& grp)
 // Store the current game
 void KWin4App::saveProperties()
 {
-  KConfig *config = KGlobal::config().data();
+  KConfig *config = KSharedConfig::openConfig().data();
 
   // Program data
   KConfigGroup cfg = config->group("ProgramData");
@@ -480,22 +475,22 @@ void KWin4App::saveProperties()
   mDoc->writeConfig(config);
 
   config->sync();
-  kDebug() << "SAVED PROPERTIES";
+  qCDebug(KFOURINLINE_LOG) << "SAVED PROPERTIES";
 }
 
 // Load current game back
 void KWin4App::readProperties()
 {
-  KConfig *config = KGlobal::config().data();
+  KConfig *config = KSharedConfig::openConfig().data();
 
   // Program data
   KConfigGroup cfg = config->group("ProgramData");
   mThemeIndexNo = cfg.readEntry("ThemeIndexNo", themeIdxFromName(mThemeDefault));
   if (mThemeIndexNo >= mThemeFiles.size()) mThemeIndexNo = 0;
-  kDebug() << "Index = " << mThemeIndexNo << " def index=" << themeIdxFromName(mThemeDefault);
+  qCDebug(KFOURINLINE_LOG) << "Index = " << mThemeIndexNo << " def index=" << themeIdxFromName(mThemeDefault);
 
 
-  kDebug() << "LOADED PROPERTIES";
+  qCDebug(KFOURINLINE_LOG) << "LOADED PROPERTIES";
 }
 
 
@@ -576,7 +571,7 @@ void KWin4App::quickStart(COLOUR startPlayer, KGameIO::IOMode input0, KGameIO::I
 // Start a new game menu
 void KWin4App::menuNewGame()
 {
-  kDebug() << "MENU NEW GAME";
+  qCDebug(KFOURINLINE_LOG) << "MENU NEW GAME";
   // End the intro if it is running
   mDoc->setGameStatus(KWin4Doc::End);
   // Init the board and Clear the old game out
@@ -670,8 +665,8 @@ void KWin4App::redoMove()
 // Set the given text into the statusbar change status message permanently
 void KWin4App::displayStatusMessage(const QString &text)
 {
-  statusBar()->clearMessage();
-  statusBar()->changeItem(text, ID_STATUS_MSG);
+  //QT5 statusBar()->clearMessage();
+  //QT5 statusBar()->changeItem(text, ID_STATUS_MSG);
 }
 
 
@@ -679,8 +674,8 @@ void KWin4App::displayStatusMessage(const QString &text)
 // the player currently moving change status mover permanently
 void KWin4App::displayStatusbarMover(const QString& text)
 {
-  statusBar()->clearMessage();
-  statusBar()->changeItem(text, ID_STATUS_MOVER);
+  //QT5 statusBar()->clearMessage();
+  //QT5 statusBar()->changeItem(text, ID_STATUS_MOVER);
 }
 
 
@@ -719,7 +714,7 @@ void KWin4App::updateStatusNames()
 // Notification that the network connection is lost.
 void KWin4App::networkBroken(int /*id*/, int oldstatus ,KGame * /*game */)
 {
-  kDebug(12010) <<  "KWin4App::networkBroken("<<oldstatus<<")";
+  qCDebug(KFOURINLINE_LOG) <<  "KWin4App::networkBroken("<<oldstatus<<")";
 
   // Set all input devices back to default
   if (mDoc->playedBy(Yellow)==0)
@@ -727,8 +722,8 @@ void KWin4App::networkBroken(int /*id*/, int oldstatus ,KGame * /*game */)
   if (mDoc->playedBy(Red)==0)
     mDoc->setPlayedBy(Red,KGameIO::MouseIO);
 
-  kDebug(12010) << "CurrrentPlayer=" << mDoc->getCurrentPlayer();
-  kDebug(12010) << "   " <<  mDoc->getPlayer(mDoc->getCurrentPlayer());
+  qCDebug(KFOURINLINE_LOG) << "CurrrentPlayer=" << mDoc->getCurrentPlayer();
+  qCDebug(KFOURINLINE_LOG) << "   " <<  mDoc->getPlayer(mDoc->getCurrentPlayer());
 
   // Activate input device
   mDoc->getPlayer(mDoc->getCurrentPlayer())->setTurn(true,true);
@@ -752,7 +747,7 @@ void KWin4App::moveDone(int /*playerNumber*/)
 // The game is over or aborted. Set status and display it.
 void KWin4App::slotGameOver(int status, KPlayer* p, KGame* /*me*/)
 {
-  kDebug() << "KWin4App::slotGameOver";
+  qCDebug(KFOURINLINE_LOG) << "KWin4App::slotGameOver";
   if (status==-1) // remis
   {
     EndGame(TRemis);
@@ -775,7 +770,7 @@ void KWin4App::slotGameOver(int status, KPlayer* p, KGame* /*me*/)
   }
   else
   {
-    kError() << "Gameover with status" << status << ". This is unexpected and a serious problem";
+    qCCritical(KFOURINLINE_LOG) << "Gameover with status" << status << ". This is unexpected and a serious problem";
   }
   checkMenus(CheckEditMenu);
 }
@@ -802,7 +797,7 @@ void KWin4App::configureNetwork()
 
   mColorGroup=new KButtonGroup(box);
   QVBoxLayout *grouplay=new QVBoxLayout(mColorGroup);
-  connect(mColorGroup, SIGNAL(clicked(int)), this, SLOT(remoteChanged(int)));
+  connect(mColorGroup, &KButtonGroup::clicked, this, &KWin4App::remoteChanged);
   connect(dlg.networkConfig(), SIGNAL(signalServerTypeChanged(int)), this, SLOT(serverTypeChanged(int)));
 
   QRadioButton *b1 = new QRadioButton(i18n("Black should be played by remote player"), mColorGroup);
@@ -852,8 +847,7 @@ void KWin4App::configureChat()
       mMyChatDlg->setPlayer(mDoc->getPlayer(Yellow));
     else
       mMyChatDlg->setPlayer(mDoc->getPlayer(Red));
-    connect(mDoc,SIGNAL(signalChatChanged(KWin4Player*)),
-            mMyChatDlg,SLOT(setPlayer(KWin4Player*)));
+    connect(mDoc, &KWin4Doc::signalChatChanged, mMyChatDlg, &ChatDlg::setPlayer);
   }
 
   if (mMyChatDlg->isHidden())
@@ -898,10 +892,10 @@ void KWin4App::configureSettings()
 
   KConfigDialog* dialog = new KConfigDialog(this, "settings", Prefs::self());
   dialog->setFaceType(KPageDialog::Plain);
-  dialog->setButtons(KDialog::Default|KDialog::Ok|KDialog::Apply|KDialog::Cancel|KDialog::Help);
-  dialog->setDefaultButton(KDialog::Ok);
+  dialog->setStandardButtons(QDialogButtonBox::Ok|QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Help);
+  dialog->button(QDialogButtonBox::Ok)->setDefault(true);
   dialog->setModal(true);
-  dialog->setHelp(QString(),"kfourinline");
+  //QT5 dialog->setHelp(QString(),"kfourinline");
   QWidget* frame = new QWidget(dialog);
   ui.setupUi(frame);
   ui.kcfg_startcolourred->setText(mTheme->colorNamePlayer(0));
@@ -909,8 +903,8 @@ void KWin4App::configureSettings()
   ui.Input0->setTitle(i18n("%1 Plays With", mTheme->colorNamePlayer(0)));
   ui.Input1->setTitle(i18n("%1 Plays With", mTheme->colorNamePlayer(1)));
   dialog->addPage(frame, i18n("General"), "games-config-options");
-  connect(dialog, SIGNAL(settingsChanged(QString)), mDoc, SLOT(loadSettings()));
+  connect(dialog, &KConfigDialog::settingsChanged, mDoc, &KWin4Doc::loadSettings);
   dialog->show();
 }
 
-#include "kwin4.moc"
+
